package implement

import (
	"code.fnuoos.com/EggPlanet/egg_models.git/src/dao"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/model"
	zhios_order_relate_logx "code.fnuoos.com/EggPlanet/egg_models.git/utils/logx"
	"reflect"
	"xorm.io/xorm"
)

func NewAdminRoleDb(engine *xorm.Engine) dao.AdminRoleDao {
	return &AdminRoleDb{Db: engine}
}

type AdminRoleDb struct {
	Db *xorm.Engine
}

func (a AdminRoleDb) FindAdminRole(id int) (*[]model.AdminRole, error) {
	var m []model.AdminRole
	if err := a.Db.Where("adm_id =?", id).Find(&m); err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}

func (a AdminRoleDb) FindAdminRoleByRoleId(id int) (*[]model.AdminRole, error) {
	var m []model.AdminRole
	if err := a.Db.Where("role_id =?", id).Find(&m); err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}

func (a AdminRoleDb) AdminDeleteBySessionForAdmId(session *xorm.Session, admId interface{}) (int64, error) {
	if reflect.TypeOf(admId).Kind() == reflect.Slice {
		return session.In("adm_id", admId).Delete(model.AdminRole{})
	} else {
		return session.Where("adm_id = ?", admId).Delete(model.AdminRole{})
	}
}

func (a AdminRoleDb) GetAdminRoleByRole(id int) (m *model.AdminRole, err error) {
	m = new(model.AdminRole)
	has, err := a.Db.Where("role_id =?", id).Get(m)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return m, nil
}
func (a AdminRoleDb) GetAdminRoleByAdminId(id int) (m *model.AdminRole, err error) {
	m = new(model.AdminRole)
	has, err := a.Db.Where("adm_id =?", id).Get(m)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return m, nil
}

func (a AdminRoleDb) AdminRoleDeleteForRoleBySession(session *xorm.Session, roleId interface{}) (int64, error) {
	if reflect.TypeOf(roleId).Kind() == reflect.Slice {
		return session.In("role_id", roleId).Delete(model.AdminRole{})
	} else {
		return session.Where("role_id = ?", roleId).Delete(model.AdminRole{})
	}
}

func (a AdminRoleDb) AdminRoleDeleteBySession(session *xorm.Session, id interface{}) (int64, error) {
	if reflect.TypeOf(id).Kind() == reflect.Slice {
		return session.In("adm_id", id).Delete(model.AdminRole{})
	} else {
		return session.Where("adm_id = ?", id).Delete(model.AdminRole{})
	}
}

func (a AdminRoleDb) BatchAddAdminRoleBySession(session *xorm.Session, mm []*model.AdminRole) (int64, error) {
	affected, err := session.Insert(mm)
	if err != nil {
		return 0, err
	}
	return affected, nil
}
