﻿package implement

import (
	"code.fnuoos.com/EggPlanet/egg_models.git/src/dao"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/model"
	zhios_order_relate_logx "code.fnuoos.com/EggPlanet/egg_models.git/utils/logx"
	"xorm.io/xorm"
)

func NewUserRelateDb(engine *xorm.Engine) dao.UserRelateDao {
	return &UserRelateDb{Db: engine}
}

type UserRelateDb struct {
	Db *xorm.Engine
}

func (u UserRelateDb) FindUserRelate(uid int64, level int) (*[]model.UserRelate, error) {
	var userRelate []model.UserRelate
	sess := u.Db.Where("uid = ?", uid)
	if level > 0 {
		sess.And("level<=?", level)
	}
	if err := sess.Asc("level").Find(&userRelate); err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if len(userRelate) == 0 {
		return nil, nil
	}
	return &userRelate, nil
}

func (u UserRelateDb) GetUserParentUserRelate(uid int64) (*model.UserRelate, error) {
	var data model.UserRelate
	get, err := u.Db.Where("level=1 and uid =?", uid).Get(&data)
	if get == false || err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &data, nil
}

func (u UserRelateDb) FindUserRelateByParentUid(uid int64, level int) (*[]model.UserRelate, error) {
	var userRelate []model.UserRelate
	sess := u.Db.Where("parent_uid = ?", uid)
	if level > 0 {
		sess.And("level<=?", level)
	}
	if err := sess.Asc("level").Find(&userRelate); err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if len(userRelate) == 0 {
		return nil, nil
	}
	return &userRelate, nil
}

func (u UserRelateDb) SumUserRelateByParentUid(parentUid string) (total int64, userRelate []*model.UserRelate, err error) {
	total, err = u.Db.Where("parent_uid = ?", parentUid).And("level = 1").FindAndCount(&userRelate)
	return
}

func (u UserRelateDb) PageFindUserRelateByParentUid(uid int64, page, pageSize int) (*[]model.UserRelate, int64, error) {
	var userRelate []model.UserRelate
	sess := u.Db.Where("parent_uid = ?", uid)
	count, err := sess.Limit(pageSize, (page-1)*pageSize).Asc("level").FindAndCount(&userRelate)
	if err != nil {
		return nil, 0, zhios_order_relate_logx.Error(err)
	}
	return &userRelate, count, nil
}
